summaryrefslogtreecommitdiffstats
path: root/src/xlsx.c
diff options
context:
space:
mode:
authorBenjamin Titmus <Benjamin.Titmus@arm.com>2020-11-13 21:24:20 +0000
committerBenjamin Titmus <Benjamin.Titmus@arm.com>2020-11-13 21:24:20 +0000
commit3806c6b10abf130d1c06e2d0fb99e9f319986f55 (patch)
tree44efba753feb50fde1c5425dec0730c394ba880a /src/xlsx.c
parentbdd936a12c68f74419e3307760439335e1b18133 (diff)
Add italic option to colors
Diffstat (limited to 'src/xlsx.c')
-rw-r--r--src/xlsx.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/xlsx.c b/src/xlsx.c
index a8d7d18..6fe9bf6 100644
--- a/src/xlsx.c
+++ b/src/xlsx.c
@@ -573,9 +573,11 @@ int export_xlsx(char * filename, int r0, int c0, int rn, int cn) {
else if ((*pp)->label) // right align
format_set_align(format, LXW_ALIGN_RIGHT);
// handle bold and underline
if ((*pp)->ucolor != NULL && (*pp)->ucolor->bold)
format_set_bold(format);
+ else if ((*pp)->ucolor != NULL && (*pp)->ucolor->italic)
+ format_set_italic(format);
else if ((*pp)->ucolor != NULL && (*pp)->ucolor->underline)
format_set_underline(format, LXW_UNDERLINE_SINGLE);
@@ -573,9 +573,11 @@ int export_xlsx(char * filename, int r0, int c0, int rn, int cn) {
else if ((*pp)->label) // right align
format_set_align(format, LXW_ALIGN_RIGHT);
- // handle bold and underline
+ // handle bold, italic and underline
if ((*pp)->ucolor != NULL && (*pp)->ucolor->bold)
format_set_bold(format);